==> nim_fluttify-0.1.2.tar.gz: example/lib/src/user_relationship/add_to_black_list.screen.dart <==
import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';
import 'package:nim_fluttify_example/src/user_relationship/black_list.screen.dart';

class AddToBlackListScreen extends StatefulWidget {
  @override
  _AddToBlackListScreenState createState() => _AddToBlackListScreenState();
}

class _AddToBlackListScreenState extends State<AddToBlackListScreen>
    with AccountTokenMixin {
  VerifyType _verifyType = VerifyType.direct;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('AddToBlackList')),
      body: Center(
        child: DecoratedColumn(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text('当前账户: $testAccount'),
            Text('待黑名单账户: $peerAccount'),
            DecoratedRow(
              itemSpacing: kSpaceNormal,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                RaisedButton(
                  onPressed: _handleAddToBlackList,
                  child: Text('发起黑名单添加'),
                ),
                RaisedButton(
                  onPressed: _handleBlackList,
                  child: Text('查看黑名单列表'),
                ),
              ],
            ),
            if (result != null) Text(result),
          ],
        ),
      ),
    );
  }

  void _handleAddToBlackList() async {
    clearResult();
    Nim.instance
        .addToBlackList(peerAccount)
        .loading(context)
        .catchError(handle(context));
  }

  void _handleBlackList() async {
    context.rootNavigator.push(
      MaterialPageRoute(builder: (context) => BlackListScreen()),
    );
  }
}

==> nim_fluttify-0.1.5.tar.gz: example/lib/src/user_relationship/add_to_black_list.screen.dart <==
import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';
import 'package:nim_fluttify_example/src/user_relationship/black_list.screen.dart';

class AddToBlackListScreen extends StatefulWidget {
  @override
  _AddToBlackListScreenState createState() => _AddToBlackListScreenState();
}

class _AddToBlackListScreenState extends State<AddToBlackListScreen>
    with AccountTokenMixin {
  P2PVerifyType _verifyType = P2PVerifyType.direct;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('AddToBlackList')),
      body: Center(
        child: DecoratedColumn(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text('当前账户: $testAccount'),
            Text('待黑名单账户: $peerAccount'),
            DecoratedRow(
              itemSpacing: kSpaceNormal,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                RaisedButton(
                  onPressed: _handleAddToBlackList,
                  child: Text('发起黑名单添加'),
                ),
                RaisedButton(
                  onPressed: _handleBlackList,
                  child: Text('查看黑名单列表'),
                ),
              ],
            ),
            if (result != null) Text(result),
          ],
        ),
      ),
    );
  }

  void _handleAddToBlackList() async {
    clearResult();
    Nim.instance
        .addToBlackList(peerAccount)
        .loading(context)
        .catchError(handle(context));
  }

  void _handleBlackList() async {
    context.rootNavigator.push(
      MaterialPageRoute(builder: (context) => BlackListScreen()),
    );
  }
}
